@@ -14,7 +14,7 @@ picasso <- function(X,
                     max.ite = 1e3,
                     verbose = FALSE)
 {
-  if (family != "gaussian" && family != "binomial" &&  family != "poisson"){
+  if (family != "gaussian" && family != "binomial" &&  family != "poisson" && family != "sqrtlasso"){
     cat(" Wrong \"family\" input. \n \"family\" should be 
            one of \"gaussian\", \"binomial\" and \"poisson\".\n", 
         family," is not supported in this version. \n")
@@ -42,6 +42,16 @@ picasso <- function(X,
                         prec = prec, max.ite = max.ite, verbose = verbose)
   }
 
+  if (family == "sqrtlasso"){
+    if(!is.matrix(Y))
+      Y = as.matrix(Y)
+    
+    out = picasso.sqrtlasso(X = X, Y = Y, lambda = lambda, nlambda = nlambda, 
+                        lambda.min.ratio = lambda.min.ratio, lambda.min = lambda.min, 
+                        method = method, gamma = gamma, standardize = standardize, 
+                        prec = prec, max.ite = max.ite, verbose = verbose)
+  }
+
   if(family=="poisson"){
     out = picasso.poisson(X = X, Y=Y, lambda = lambda, nlambda = nlambda, 
                         lambda.min.ratio = lambda.min.ratio,
